@@ -1,4 +1,4 @@
-# Copyright 2015-2016 F-Secure
+# Copyright 2015-2017 F-Secure
 
 # Licensed under the Apache License, Version 2.0 (the "License"); you
 # may not use this file except in compliance with the License.  You may
@@ -51,7 +51,7 @@ import libvirt
 import xml.etree.ElementTree as etree
 
 from see.context.resources import resources
-from see.context.resources.helpers import subelement
+from see.context.resources.helpers import subelement, tag_disk
 
 
 def domain_xml(identifier, xml, disk_path):
@@ -131,6 +131,7 @@ class VBoxResources(resources.Resources):
     def allocate(self):
         """Initializes libvirt resources."""
         disk_path = self.provider_image
+        tag_disk(disk_path)
 
         self._hypervisor = libvirt.open(
             self.configuration.get('hypervisor', 'vbox:///session'))
